 * Activity 2 answers;

* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; TITLE;

* Location for files to be saved - CHANGE THESE TO YOUR DIRECTORIES;
LIBNAME activity "F:\13_ICPSR\Download\Activities";

* Importing SAS dataset into work library;
DATA work.activity; SET activity.SAS_Activity_Data;
	* Computing person mean stress to use as predictor;
	pmstress = MEAN(OF stress1-stress5);
	* Stacking data; 
	month=1; severity=severity1; stress=stress1; OUTPUT;
	month=2; severity=severity2; stress=stress2; OUTPUT;
	month=3; severity=severity3; stress=stress3; OUTPUT;
	month=4; severity=severity4; stress=stress4; OUTPUT;
	month=5; severity=severity5; stress=stress5; OUTPUT;
	* Labeling all variables;
	LABEL 	PersonID = 	"PersonID: Unique Identifier"
			baseage = 	"baseage: Age at Baseline"
			treat = 	"treat: Treatment Group (1=control, 2=treatment)"
			month =	 	"month: Month of Study"
			severity = 	"severity: Time-Varying Severity Outcome"
			stress =	"stress: Time-Varying Stress Predictor"
			pmstress = 	"pmstress: Person-Mean Stress Predictor";
	* Dropping unnecessary multivariate variables;
	DROP severity1-severity5 stress1-stress5;
RUN;

* Creating and centering predictor variables for analysis;
DATA work.activity; SET work.activity;
	* Center month here;
	month1 = month - 1; LABEL month1 = "month1: Month Centered at 1";
RUN;

***********************************************************************
*****				 Refresher on PROC MIXED 					  *****
***********************************************************************/

* PROC MIXED syntax commands used below: 

PROC MIXED:
	DATA gives file used for analysis
	METHOD=REML specifies restricted ML or ML (REML is default)
	COVTEST gives significance tests of covariance parameters
	NOCLPRINT suppresses class variable list
	NOITPRINT suppresses iteration history (but use for troubleshooting)
	MAXITER=1000 increases #iterations to 1000
CLASS: defines categorical variables
	Observation identifiers (PersonID, month) are categorical
MODEL: defines equation, where [outcome] = [predictors]
	/ SOLUTION asks for parameter estimates
	  DDFM=Satterthwaite specifies Satterthwaite denominator DF
RANDOM: lists random effects (INTERCEPT is not included by default)
	  TYPE=UN specifies unstructured matrix (all variances & covariances)
	/ SUBJECT=PersonID defines nesting structure for level 2 persons
	/ G, GCORR prints covariance, correlation matrix of random effects
	/ V, VCORR prints combined covariance, correlation matrix from G and R
REPEATED: allows structuring of the residual variance and repeated measures
	Day indicates level-1 nesting (days within persons)
	/ TYPE= specifies covariance structure (see SAS manual for list)
	/ R, RCORR asks for covariance and correlation matrices
	REPEATED is included by default for random effects models
	with TYPE=VC (is identity matrix --> equal variances no covariances); 

* Now it's your turn!;


* 1: Empty Model and ICC (=.41);
TITLE1 "Random Intercept Only Baseline Model (equal to Compound Symmetry)";		
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
	CLASS PersonID month;	
  	MODEL severity =  / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT / G V VCORR TYPE=UN SUBJECT=PersonID;	
  	REPEATED month / R RCORR TYPE=VC SUBJECT=PersonID;
RUN; TITLE1;


* 2: Saturated means, unstructured R matrix model;
***  Means are declining over time, which is informative for fixed effects;
*** Variances and covariances decrease, then increase over time;
*** Informative for what kind of variance model we'll need;
TITLE1 "Saturdated Means, Unstructured R Baseline Model";		
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
	CLASS PersonID month;	
  	MODEL severity = month / SOLUTION DDFM=SATTERTHWAITE;		
  	REPEATED month / R RCORR TYPE=UN SUBJECT=PersonID;
	LSMEANS month; 
RUN; TITLE1;

* 3: Polynomial fixed and random effects models;

TITLE1 "Fixed Linear, Random Intercept Only Model";
* P-value for month1 is signif, so model fits better;	
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
	CLASS PersonID month;	
  	MODEL severity = month1 / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT / G V VCORR TYPE=UN SUBJECT=PersonID;	
  	REPEATED month / R RCORR TYPE=VC SUBJECT=PersonID; 
RUN; TITLE1;

TITLE1 "Random Linear Model";
* REML deviance difference for df=2 is signif, so model fits better;	
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
	CLASS PersonID month;	
  	MODEL severity = month1 / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 / G V VCORR TYPE=UN SUBJECT=PersonID;	
  	REPEATED month / R RCORR TYPE=VC SUBJECT=PersonID; 
RUN; TITLE1;

TITLE1 "Fixed Quadratic, Random Linear Model";
* P-value for month1*month1 is NOT signif, so model does not fit better;	
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
	CLASS PersonID month;	
  	MODEL severity = month1 month1*month1 / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 / G V VCORR TYPE=UN SUBJECT=PersonID;	
  	REPEATED month / R RCORR TYPE=VC SUBJECT=PersonID; 
RUN; TITLE1;

TITLE1 "Random Quadratic Model";
* REML deviance difference for df=3 is signif, so model fits better;	
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
	CLASS PersonID month;	
  	MODEL severity = month1 month1*month1 / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / G V VCORR TYPE=UN SUBJECT=PersonID;	
  	REPEATED month / R RCORR TYPE=VC SUBJECT=PersonID; 
RUN; TITLE1;

* 4: Interpretation of final random quadratic model:

Calculating 95% random effects confidence intervals to interpret variance components:
CI = fixed effect  2*SQRT(variance)
Intercept CI = 			15.849  2*SQRT(9.433)   9.71 to 21.99
Linear Slope CI =		 -.716  2*SQRT(2.587) 	-3.93 to 2.50
Quadratic Slope CI =	  .052  2*SQRT(.134) 	-0.68 to 0.78

Summary of Final Model Parameters: 
The average expected value of Y at the first occasion (because month is centered at 1) is 15.849, 
and this is expected to fall between 9.71 and 21.99 for 95% of the individuals in the sample. 
There is a significant instantaneous linear rate of decline of -.716/month as evaluated at the 
first occasion, and this linear effect of time varies significantly over individuals. 
Specifically, the linear slope is predicted to fall between -3.93 and 2.50 for 
95% of the individuals in the sample. so not everyone is predicted to decline 
(as evaluated at the first occasion). 
Although the average deceleration in the linear rate of decline of .052/month is not significant, 
significant individual differences were found, such that the 95% confidence interval for the 
quadratic effect of time was -.68 to .78. Thus, individuals are predicted to demonstrate both 
acceleration and deceleration of the initial negative trend. The interpretation of the 
quadratic coefficient is such that for every additional month, the linear coefficient 
of -.716 becomes .104 less negative 
(quadratic coefficient * 2 describes how the linear trend changes per unit time);
