 * Activity 3 answers;

* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; TITLE;

* Location for files to be saved - CHANGE THESE TO YOUR DIRECTORIES;
LIBNAME activity "F:\13_ICPSR\Download\Activities";

* Importing SAS dataset into work library;
DATA work.activity; SET activity.SAS_Activity_Data;
	* Computing person mean stress to use as predictor;
	pmstress = MEAN(OF stress1-stress5);
	* Stacking data; 
	month=1; severity=severity1; stress=stress1; OUTPUT;
	month=2; severity=severity2; stress=stress2; OUTPUT;
	month=3; severity=severity3; stress=stress3; OUTPUT;
	month=4; severity=severity4; stress=stress4; OUTPUT;
	month=5; severity=severity5; stress=stress5; OUTPUT;
	* Labeling all variables;
	LABEL 	PersonID = 	"PersonID: Unique Identifier"
			baseage = 	"baseage: Age at Baseline"
			treat = 	"treat: Treatment Group (1=control, 2=treatment)"
			month =	 	"month: Month of Study"
			severity = 	"severity: Time-Varying Severity Outcome"
			stress =	"stress: Time-Varying Stress Predictor"
			pmstress = 	"pmstress: Person-Mean Stress Predictor";
	* Dropping unnecessary multivariate variables;
	DROP severity1-severity5 stress1-stress5;
RUN;

* Creating and centering predictor variables for analysis;
DATA work.activity; SET work.activity;
	* Your predictor centering code goes here -- make sure to add labels;
	month1 = month - 1; 
		LABEL month1 = "month1: Month Centered at 1";
	* ADD YOUR SYNTAX FOR CENTERING PREDICTORS IN ACTIVITY 3 HERE;
	age40 = baseage - 40; 	
		LABEL age40 = "age40: Age at Baseline (0=40)";
	     IF treat=1 THEN DO; treat0=0; END;
	ELSE IF treat=2 THEN DO; treat0=1;  END;	
		LABEL treat0 = "treat0: Treatment Group (0=C, 1=T)";

RUN;

***********************************************************************
*****				 Refresher on PROC MIXED 					  *****
***********************************************************************/

* PROC MIXED syntax commands used below: 

PROC MIXED:
	DATA gives file used for analysis
	METHOD=REML specifies restricted ML or ML (REML is default)
	COVTEST gives significance tests of covariance parameters
	NOCLPRINT suppresses class variable list
	NOITPRINT suppresses iteration history (but use for troubleshooting)
	MAXITER=1000 increases #iterations to 1000
CLASS: defines categorical variables
	Observation identifiers (PersonID, month) are categorical
MODEL: defines equation, where [outcome] = [predictors]
	/ SOLUTION asks for parameter estimates
	  DDFM=Satterthwaite specifies Satterthwaite denominator DF
RANDOM: lists random effects (INTERCEPT is not included by default)
	  TYPE=UN specifies unstructured matrix (all variances & covariances)
	/ SUBJECT=PersonID defines nesting structure for level 2 persons
	/ G, GCORR prints covariance, correlation matrix of random effects
	/ V, VCORR prints combined covariance, correlation matrix from G and R
REPEATED: allows structuring of the residual variance and repeated measures
	Day indicates level-1 nesting (days within persons)
	/ TYPE= specifies covariance structure (see SAS manual for list)
	/ R, RCORR asks for covariance and correlation matrices
	REPEATED is included by default for random effects models
	with TYPE=VC (is identity matrix --> equal variances no covariances); 

* Now it's your turn!;


* Baseline unconditional model;
TITLE1 "Random Quadratic Unconditional Baseline Model";
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN; TITLE1;

* 1: Effects of age (age 40 as reference):
	 Main effect of age --> effect on severity at month1=0
	 Age*month1 --> effect on linear slope for month
	 Age*month1*month1 --> effect on quadratic slope for month;

TITLE1 "Add 3 Effects of age";
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40 month1*age40 month1*month1*age40 
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN; TITLE1;

TITLE1 "Drop age by quadratic month";
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40 month1*age40 
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN; TITLE1;

TITLE1 "Drop age by linear month - final age model";
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40  
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN; TITLE1;

* 2: Effects of group using control as a reference;
TITLE1 "Coontrol vs. treatment group full model";
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40  
					 treat0 month1*treat0 month1*month1*treat0
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN; TITLE1;

TITLE1 "Drop group by quadratic month";
PROC MIXED DATA=work.activity NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40  
					 treat0 month1*treat0
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
	ESTIMATE "a) Random assignment check (group diff at month 1)"	treat0 1 treat0*month1 0;
	ESTIMATE "b) Control group linear slope at month 1" 			month1 1 month1*month1 0 treat0*month1 0;
	ESTIMATE "c) Control group linear slope at month 5"				month1 1 month1*month1 8 treat0*month1 0;
	ESTIMATE "d) Treatment group linear slope at month 1" 			month1 1 month1*month1 0 treat0*month1 1;
	ESTIMATE "e) Treatment group linear slope at month 5" 			month1 1 month1*month1 8 treat0*month1 1;
	ESTIMATE "f) Treatment group diff in linear slope at month 1" 	treat0*month1 1;
	ESTIMATE "g) Treatment group diff in linear slope at month 5" 	treat0*month1 1;
	ESTIMATE "h) Group diff at month 5"								treat0 1 treat0*month1 4;
RUN; TITLE1;




