﻿
* Activity 4 answers.

* Define locations of files used in examples -- CHANGE THIS.
FILE HANDLE activity /NAME = "F:\13_ICPSR\Download\Activities".
GET FILE = "activity/SPSS_Activity_Data.sav".
DATASET NAME activity WINDOW=FRONT.

* Getting person mean stress (for later).
COMPUTE pmstress = MEAN(stress1 TO stress5).
VARIABLE LABELS PMstress "Person Mean Stress".
EXECUTE.

* Stacking data for MIXED.
VARSTOCASES
	/MAKE severity FROM severity1 TO severity5
	/MAKE stress FROM stress1 TO stress5
	/INDEX month (5)
	/KEEP = ALL
	/NULL = DROP.

* Labeling all variables.
VARIABLE LABELS 	
   PersonID 	"PersonID: Unique Identifier"
			baseage  	"baseage: Age at Baseline"
			treat 	   "treat: Treatment Group (1=control, 2=treatment)"
			month  	 	"month: Month of Study"
			severity 	"severity: Time-Varying Severity Outcome"
			stress   	"stress: Time-Varying Stress Predictor"
			pmstress 	"pmstress: Person-Mean Stress Predictor".
EXECUTE.

* Center time at first occasion.
COMPUTE month1 = month - 1.
VARIABLE LABELS month1 "Month of Study (0=1)".

* Add the rest of your centered variables here.
COMPUTE age40 = baseage - 40.
IF (treat=1) treat0=0.
IF (treat=2) treat0=1.
VARIABLE LABELS   
	  age40  "Age at Baseline (0=40)"
			treat0 "Treatment Group (0=no, 1=yes)".
EXECUTE.

* Centering level-2 predictor of stress.
COMPUTE pmstress5 = pmstress - 5.
VARIABLE LABELS pmstress5 "Person Mean Stress (0=5)".

* PERSON-Mean-Centering level-1 predictor of stress.
COMPUTE wpstress = stress - pmstress.
VARIABLE LABELS wpstress "Within-Person Stress (0=PM)".
EXECUTE.

***********************************************************************
*****			          Multilevel Analysis using SPSS MIXED		          *****
***********************************************************************.	

* General form of MIXED:
MIXED dv BY categorical and nesting variables WITH continuous variables
	/METHOD  = REML (default) or ML
	/PRINT   = regression solution, tests of covariances, G and R matrices
	/FIXED   = model predictors and interactions
	/RANDOM  = INTERCEPT random effects | SUBJECT(idvar) COVTYPE(unstructured)
	/REPEATED = categorical time | SUBJECT(idvar) COVTYPE(whatever structure).

DATASET ACTIVATE activity.

* 2:ICC for Stress (=.70 BP, =.30 WP).
TITLE "Random Intercept Only Baseline Model (equal to Compound Symmetry)".
MIXED stress BY PersonID month  
	/METHOD = ML
	/PRINT = SOLUTION TESTCOV 
	/FIXED =  
	/RANDOM = INTERCEPT | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.


* 2: Main effects of stress using person mean centering.
TITLE "PMC stress main effects model".
MIXED severity BY PersonID month WITH month1 age40 treat0 pmstress5 wpstress
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV 
	/FIXED  = month1 month1*month1 age40 treat0 treat0*month1
		         pmstress5 wpstress 
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID)
	/TEST "a) BP effect" 			      pmstress5 1
	/TEST "b) Contextual effect"		pmstress5 1 wpstress -1
	/TEST "c) WP effect"				      wpstress 1.
TITLE.

* 3: Interactive effects of stress using person mean centering.
TITLE "PMC stress interactive effects model".
MIXED severity BY PersonID month WITH month1 age40 treat0 pmstress5 wpstress
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV 
	/FIXED  = month1 month1*month1 age40 treat0 treat0*month1
		         pmstress5 wpstress pmstress5*pmstress5 pmstress5*wpstress
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID)
	/TEST "a) BP interaction" 		pmstress5*pmstress5 1
	/TEST "b) WP interaction"		 pmstress5*wpstress 1.
TITLE.

