****** Make Friends with SAS, Day 1, Data Manipulation;
****** Created by Lesa Hoffman;

*******************************************************************************
*******				SAS SYNTAX AND DATA NAME RULES						*******
******************************************************************************;

***** WRITE COMMENTS TO HELP YOU! *****;
/* You can comment like this for large chunks of code */
* Or you can comment line by line as needed like this;
* Try not to use unmatched quotes in comments, or SAS gets confused;

/* 	USE COLORS TO HELP YOU!
	Comments are GREEN 
   	SAS system commands are BLUE
   	Variables and file names are BLACK
   	Entered data should be shaded YELLOW
   	If you see RED, something is wrong 
   	Libraries and Labels are PURPLE
		-- anything in PURPLE is case-sensitive and space-sensitive
   	Otherwise SAS is NOT case-sensitive or space-sensitive  */
   
* Each SAS command (that starts with a BLUE word) must end with a semi-colon;

* SAS dataset names have two parts, separated by a period: Library.Filename
	Library = where the file is located on your computer
			  the default place is "work", which is a temporary directory
			  "work" is the safest place to store data files when you are 
			  transforming them because it wont ruin anything permanent
	Filename = name of file (without extension)
You can have as many different libraries (places) and files as you want;


************************************************
***   IMPORTING AND EXPORTING SAS DATASETS   ***
************************************************;

* Step 1: Tell SAS where your data files are by making a library;
* Step 2: Tell SAS the old (SET) and new (DATA) names of the datafile;

* A LIBRARY is name for a specific PLACE (not a file) on your computer
  LIBRARY names must be 8 characters or less, with no special characters
  Once you have defined a library using a LIBNAME staement, you can access 
  existing SAS data sets or save newly created data sets to a permanent file;

* Step 1: I have named my library "filepath";
LIBNAME filepath "F:\13_Psyc930SAS\Day1_DataManipulation";

* Your turn;
LIBNAME lesa "C:\Users\Attention\Desktop\13_ICPSR\Download\SAS\Make Friends with SAS\Day1_DataManipulation";


* It is a REALLY GOOD IDEA to immediately copy whatever file you
  will be working with to the "work" library, which is a temporary location;

* DATA creates a new SAS data set in the work library called "newsasfile"
  FROM (SET) the permanent SAS file "oldsasfile" in the "filepath" location;
DATA work.newsasfile;
	SET filepath.oldsasfile;
RUN;

* This code is equivalent -- if you dont specify a library, it goes to "work";
DATA newsasfile;
	SET filepath.oldsasfile;
RUN;

* Your turn;
DATA work.saspractice;
	SET lesa.saspractice;
RUN;


* To save a SAS file from temporary "work" to permanent library
  DATA creates a SAS data set in the permanent library called "sasfilesaved"
  FROM (SET) the existing SAS file "sasfile" in the "work" location;
DATA filepath.sasfilesaved;
	SET work.sasfile;
RUN;

* Your turn;



*************************************************
***   IMPORTING AND EXPORTING SPSS DATASETS   ***
************************************************;

* IMPORT SPSS data using exact, hard-coded path, filename, and extension;
* New SAS file is in "work" library and is called "spssfile";
* DBMS ("database management system") tells SAS what kind of file it is
* "REPLACE" means write over it if it already exists (is ok in "work");
PROC IMPORT DATAFILE="F:\13_Psyc930SAS\Day1_DataManipulation\spssfile.sav" 
	OUT=work.spssfile DBMS=SAV REPLACE;
RUN;

* Your turn;


* SAS does NOT have value labels for variables like SPSS does
  SAS has "formats", which are labels that can be used in data and/or output
  Variables with SPSS value labels are read in as formats by default
  This means your original variable values are not visible, and 
  categorical variables are now sorted by their labels, not their values;

* To fix it, save it as itself using same data name on DATA and SET
  and add a FORMAT statement that removed all formats from data
  The keyword _ALL_ refers to all variables, or you can list specific variables;
DATA work.spssfile; 
	SET work.spssfile; 
	FORMAT _ALL_; 
RUN;

* Your turn;


* To print what formats for value labels were imported, use FMTLIB;
PROC FORMAT FMTLIB LIBRARY=work.formats; 
RUN;
* To save formats to a separate SAS dataset, use CNTLOUT and name new datafile;
PROC FORMAT CNTLOUT=work.DataFormats LIBRARY=work.formats; 
RUN;

* By default SAS shows variable labels instead of names -- here is how to fix it

1) Select the SAS Explorer window to make it the active window.
2) Select Tools->Options->Explorer... from the pull-down menu.
3) Select the "Members" tab on the Explorer Options window.
4) Select "Table" and then hit "Edit".
5) Select "&Open" and then hit "Edit"
6) Add "colheading=name" (no quotes) to the action command.
7) Repeat steps 4-6 for member type &View Columns.
8) OK your way out of the Explorer Options window.


* EXPORT to SPSS data using exact, hard-coded path, filename, and extension
  DATA says what SAS file to export, OUTFILE says where file goes, DBMS says what kind;
PROC EXPORT DATA=work.spssfile OUTFILE="F:\13_Psyc930SAS\Day1_DataManipulation\newspssfile.sav" 
	DBMS=SAV REPLACE; 
RUN;

* Your turn;



* Importing any kind of non-SAS data requires an exact file path 
  To make it easier on ourselves, we use use a macro variable "filepath";

* A MACRO variable is a programming variable that works like "find & replace"
  Here, "filepath" functions like a library and abbreviates the path
  Then, if you change your folder you only need to change it ONCE below;

* %LET statement defines a macro variable for the file path we wrote out before;
%LET filepath=F:\13_Psyc930SAS\Day1_DataManipulation_Lecture;

* Now we can use this abbreviation by adding "&" in front and "." in back;	
PROC EXPORT DATA=work.spssfile OUTFILE="&filepath.\newspssfile.sav" 
	DBMS=SAV REPLACE; 
RUN;

* Your turn;



**************************************************
***  IMPORTING AND EXPORTING EXCEL WORKSHEETS  ***
*************************************************;

* IMPORT: New SAS data set in the work library called "excelfile"
  from the Excel workbook in DATAFILE= location from SHEET= 
  "GETNAMES" reads in the first row as variable names;
	
* Using abbreviated path we just made to import OLD version of excel files xls;
PROC IMPORT DATAFILE="&filepath.\excelfile.xls" OUT=work.excelfile DBMS=EXCEL REPLACE; 
	SHEET="sheetname"; 
	GETNAMES=YES; 
RUN;

* Your turn;



* Using abbreviated path we just made to import NEW version of excel files xlsx;
PROC IMPORT DATAFILE="&filepath.\excelfile.xlsx" OUT=work.excelfilex DBMS=XLSX REPLACE; 
	SHEET="sheetname"; 
	GETNAMES=YES; 
RUN;


* Your turn;



* EXPORT: DATA lists file to be exported, OUTFILE lists name and location of new file;
* Using abbreviated path we just made;
PROC EXPORT DATA=work.excelfile OUTFILE="&filepath.\excelfilesaved.xls" DBMS=EXCEL REPLACE; 
RUN;
PROC EXPORT DATA=work.excelfile OUTFILE="&filepath.\excelfilesaved.xlsx" DBMS=XLSX REPLACE; 
RUN;

* Your turn;



********************************************************************
***  IMPORTING/EXPORTING EXCEL FILES IF ENGING IS NOT INSTALLED  ***
*******************************************************************;

* Certain versions of SAS do not permit the IMPORT/EXPORT procedures to be used
  with excel. In that case, it is best to save the excel file as a .csv file,
  a comma-delimited file, and import/export it in that format instead;

***** TO IMPORT A CSV FILE;
PROC IMPORT DATAFILE="&filepath.\csvfile.csv" OUT=work.csvfile DBMS=CSV REPLACE;  
	DATAROW=2;		* Which row to start importing from;
	GETNAMES=YES;   * Select NO if there are no names on the top row;
RUN;

***** TO EXPORT TO A CSV FILE (useful for Mplus);
PROC EXPORT DATA=work.excelfile OUTFILE="&filepath.\csvfilesave.csv" DBMS=CSV REPLACE; 
RUN;


*********************************************
***  EXPORTING DATA AS FIXED-FORMAT FILE  ***
********************************************;

* FILE refers to file to be saved to;
* PUT prints listed variables starting at column 2 (@2);
* ( +(-1) ) means no spaces in between;
DATA sasfile; SET sasfile;
	FILE "&filepath.\fixfile.dat";  
	PUT @2 (ID var1 var2 var3) ( +(-1) ); 
RUN;


**********************************************
***  EXPORTING DATA AS TAB-DELIMITED FILE  ***
*********************************************;

* FILE refers to file to be saved to;
* PUT prints listed variables (no names at top);
DATA sasfile; SET sasfile;
	FILE "&filepath.\tabfile.dat"; 
	PUT ID var1 var2 var3; 
RUN;


************************************
***  ENTERING DATA FROM SCRATCH  ***
************************************;

* DATALINES also known as CARDS
  Labels can be up to 256 characters
  Labels used in a DATA step will stay with the data;
* Use INPUT statement to list variable names in order, can add labels,  
  and then type in data with one space between variables;
DATA newsasfile;
	INPUT varname1 varname2;		
		LABEL varname1="Label for First Variable"						
		      varname2="Label for Second Variable";
	DATALINES;											
	1 1
	2 2
; RUN;
	



*******************************************************************************
*******				TRANSFORMATIONS TO SAS DATASETS						*******
******************************************************************************;

********************************
***  KEEP or DROP Variables  ***
*******************************;

* The following commands can be used in DATA steps:
	KEEP	keeps listed variables only
	DROP	drops listed variables only
	RETAIN	re-orders variables as listed in file
			must be used immediately after DATA command
    By default, all variables are kept;

* Here, we make a new dataset that KEEPS only 3 variables;
DATA work.shorterdatafilename; 
	SET work.datafilename; 
	KEEP ID var1 var2;
RUN;

* Here, we make a new dataset that DROPS only 3 variables;
DATA work.shorterdatafilename; 
	SET work.datafilename; 
	DROP ID var1 var2;
RUN;

* Can abbreviate lists of variables for KEEP and DROP two ways:
		"-"  refers to variables numerically
		"--" refers to variables positionally	
	var1-var50 refers to var1, var2, var3...var50
	var1--var50 refers to var1, (next var in file)... var50;

* We can use RETAIN to re-order variables in dataset;
* Any variables not listed on RETAIN get same place in dataset;
* RETAIN must be used IMMEDIATELY after the DATA command;
* Here, we want "firstvar" first and "secondvar" to be second;
* All other variables get put after it in original order;
DATA work.newdatafilename;
	RETAIN firstvar secondvar;
	SET work.datafilename;
RUN;



****************************
***  KEEP or DROP Cases  ***
***************************;

* WHERE statement is like FILTER in SPSS;
* WHERE can appear after any DATA or PROC statement 
  Select cases using conditional operators: EQ, NE, GT, LT, 
  GE, LE, AND, OR, IS NOT MISSING, or other functions like NMISS;

* This creates a new dataset with only cases where Sex=1;
DATA work.girlsonly; 
	SET work.olddata;
	WHERE Sex=1;
RUN;

* This creates a new dataset with only cases where Sex=1 and group=1;
DATA work.girlsgroup1only; 
	SET work.olddata;
	WHERE Sex=1 AND group=1;
RUN;

* This creates a new dataset with only complete cases for var1 and var2; 
DATA work.completecases; 
	SET work.olddata;
	WHERE NMISS(var1, var2)=0;
RUN;

* Your turn;



*******************************************************
***  RENAMING VARIABLES AND ADDING VARIABLE LABELS  ***
******************************************************;

* Adding meta data to variables must be done in a DATA step
  Using same name on DATA/SET saves as itself;

* Adding a variable label to variable "newvar";
DATA work.datafile; 
	SET work.datafile;
	LABEL newvar="newvar: Lesa's Label of New Variable";
RUN;

* There is no such thing as missing value codes in SAS -- leave it blank;

* Rename 2 variables;
DATA work.datafile; 
	SET work.datafile;
	RENAME oldvar1=newvar1 oldvar2=newvar2;
	* Labels still refer to OLD variable name because RENAME is processed last!!!;
	LABEL oldvar1= "newvar1: Label of New Variable1"
		  oldvar2= "newvar2: Label of New Variable2";
RUN;

* Your turn;



*******************************
***  CREATING VALUE LABELS  ***
******************************;

* Use PROC FORMAT instead to create VALUE labels to use in data or analyses later;

* Here, we create two new formats called "FGender" and "Fgroup";
PROC FORMAT LIBRARY=work;
	VALUE FGender 0="Male" 1="Female";
	VALUE FGroup  0="Control" 1="Treatment";
RUN;
* Now we add the new format to a variable by adding "." after it in a FORMAT statement;
DATA work.datafile;
	SET work.datafile;
	FORMAT female Fgender. group Fgroup.;
RUN;

* Your turn;



**********************
***  SORTING DATA  ***
*********************;

* Sort BY variables, ascending by default (add DESCENDING before variable otherwise);
PROC SORT DATA=work.datafilename; 
	BY ID time;  * List as many variables as you want, in order;
RUN;

* Your turn;



* PROC SORT can be used to eliminate duplicates: 
  NODUPKEY = all observations with the same BY values will be deleted.
  Sorted, non-duplicate dataset is saved via OUT as "sorteddatafilename" 
  Duplicate cases get saved via DUPOUT into "duplicates" instead;
PROC SORT DATA=work.datafilename NODUPKEY OUT=work.sorteddatafilename DUPOUT=work.duplicates; 
	BY var1 var2;  * List variables to select for duplicates on;
RUN;


********************************************
***  Adding CASES (rows) to a data file  ***
*******************************************;

* DATA step names file to be created from merged datasets.
  MERGE lists datasets to be combined when ADDING CASES.
  SET can also be used when ADDING CASES.
  If variables differ, those cases without will get missing values.
  Here, observations will be ordered by ID and then by time;

PROC SORT DATA=work.cases1; 
	BY ID time; 
RUN;
PROC SORT DATA=work.cases2; 
	BY ID time; 
RUN;
DATA work.allcases; 
	MERGE work.cases1 work.cases2; 
	BY ID time; 
RUN; 


***************************************************
***  Adding VARIABLES (columns) to a data file 	***
**************************************************;

* DATA step names file to be created from merged datasets.
  MERGE lists datasets to be combined when ADDING VARIABLES.
  Cases will be merged BY ID. SET will not work here!
  If there are common variables across datasets, 2nd will overwrite 1st.	
  Each file MUST be sorted by ID and time first;

PROC SORT DATA=work.dataset1; 
	BY ID time; 
RUN;
PROC SORT DATA=work.dataset2; 
	BY ID time; 
RUN;
DATA work.allvars; 
	MERGE work.dataset1 work.dataset2; 
	BY ID time; 
RUN; 


***************************************************
***  Updating a MASTER data file with new data 	***
**************************************************;

* UPDATE statements updates first dataset with second dataset.
  Missing data from "newfile1" file do not overwrite values in master.
  Data from "newfile2" would then be added where needed, and so on.
  Must be sorted by ID 1st, ID must be unique in master;

PROC SORT DATA=work.master;   
	BY ID; 
RUN;
PROC SORT DATA=work.newfile1; 
	BY ID; 
RUN;
PROC SORT DATA=work.newfile2; 
	BY ID; 
RUN;
DATA work.newestdata; 
	UPDATE work.master work.newfile1 work.newfile2; 
	BY ID; 
RUN; 
		
	
*****************************************************************
***  Go from MULTIVARIATE (wide) data to STACKED (long) data  ***
****************************************************************;

* Creates stacked variables wave, IV, and DV for each time point. 
  All other variables are copied down the rows by default.
  Must include all variables per time point on same line before OUTPUT. 
  OUTPUT then writes the new line of data.
  Note: all old multivariate variables get included still. 
  If a variable is missing, you must explicitly include the "."
  See example using ARRAYS to do this more efficiently;

* First import existing multivariate data;
PROC IMPORT DATAFILE="&filepath.\multivprac.sav" OUT=work.multivprac DBMS=SAV REPLACE;
RUN;
* Now created "stacked" version of data;
DATA work.stackprac; 		* New file;
	SET work.multivprac;    * Old file;
		wave=1; DV=DVTime1; age=AgeTime1; OUTPUT;	* One OUTPUT row per occasion; 
		wave=2; DV=DVTime2; age=AgeTime2; OUTPUT;	
		wave=3; DV=DVTime3; age=AgeTime3; OUTPUT;		
		wave=4; DV=DVTime4; age=AgeTime4; OUTPUT; 
	LABEL wave= "wave: occasion of measurement"
		  DV=   "DV: New Dependent Variable over time"
		  age=  "age: New Age over time";
* The original multivariate variables will still be in the file
  Deleting them is unnecessary, but if you wanted to, here is how;
	* Demonstrating numeric abbreviation -;
		 DROP DVTime1-DVTime4 AgeTime1-AgeTime4;
	* Demonstrating positional abbreviation --;
		* DROP DVTime1--AgeTime4;
RUN; 

/*  ARRAY is a short-hand for a list of variables
	ARRAY names must not duplicate any variable names
    Parentheses after array name is #variables, followed by variable list -
    Arraynam(1)=var1, arraynam(2)=var2, etc  

* Here is an example that uses ARRAYs to do multivariate --> stacked data;
* Use a separate ARRAY statement for each variable group;
* Change default counting to 13-17 to be consistent with activity data;
DATA work.stackprac2; 	    * New file;
	SET work.multivprac;	* Old file;
	ARRAY aDV  (1:4) DVTime1-DVTime4;
	ARRAY aAge (1:4) AgeTime1-AgeTime4;
	* Write 4 lines of data for wave 1 to 4;
	DO wave=1 TO 4 BY 1;
		DV=aDV(wave); Age=aAge(wave); OUTPUT;
	END;
RUN;
*/

*****************************************************************
***  Go from STACKED (long) data to MULTIVARIATE (wide) data  ***
****************************************************************;

* You can use PROC TRANSPOSE to make only ONE variable multivariate at a time.
  See example at end using ARRAYS to do this for more than one variable;

* First specify OLD (DATA=) and NEW (OUT=) dataset names
  PREFIX will add that text to beginning of new transposed variables.
  Transpose BY each level - aggregates into one row per unique value.
  List all constant variables on BY statement, too.
  ID - Variable that names the new columns.
  VAR - Variables to be transposed;

PROC TRANSPOSE DATA=work.stacked OUT=work.mult PREFIX=Wave_;		
	BY ID gender;	* Transpose per unique value of BY;													
	ID wave;		* Variable to define new columns;																	
	VAR DV;			* Variable in old rows;					
RUN;


/* Here is an example that uses ARRAYs to do stacked --> multivariate data;
* Make sure data are sorted by idnum and time first;
DATA work.multivprac2; SET work.stackprac; BY ID;
	* Tell it to keep ID and new multivariate variables (and whichever others);
	KEEP ID Gender DVTime1-DVTime4 AgeTime1-AgeTime4;
	* RETAIN here is used to hang onto values across rows;
	RETAIN DVTime1-DVTime4 AgeTime1-AgeTime4;
	* Separate ARRAY for each group of variables to be restructured;
	ARRAY aDV (1:4) DVTime1-DVTime4;
	ARRAY aAge(1:4) AgeTime1-AgeTime4;
		* If is first row for that ID, set all initially to 0;
		IF FIRST.ID THEN DO;
			* Do for all 4 waves;
			DO i=1 TO 4 BY 1; 
				aDV(i)=0; aAge(i)=0; 
			END;
		END; 
		* Now copy stacked data into new variables using "wave" as index;
		aDV(wave)=DV; aAge(wave)=Age; 
		* If is last for that id, write new line of data;
		IF LAST.ID THEN OUTPUT;	
RUN; 
*/

***************************************************
***  Aggregating/summarizing data across rows 	***
**************************************************;

* PROC MEANS can be used to create summary data across observations.
  BY gives you a summary per unique value.
  NOPRINT suppresses output -- it is unnecessary here. 
  VAR lists variables to be summarized.
  OUTPUT OUT= lists datafile new summary variables get saved to.
  Many available functions: MEAN, STD, SUM, MIN, MAX, N, NMISS... 
  Format: FUNCTION(variable names) = new variable names;

* Data MUST be sorted with the BY variable first;
PROC SORT DATA=work.datafilename; 
	BY ID; 
RUN;
PROC MEANS NOPRINT DATA=work.datafilename;  * NOPRINT suppresses output;
	BY ID;				    * Summary per value of ID;
	VAR var1 var2; 			* Do it for these variables;	
	OUTPUT OUT=work.summaryfile
		MAX (var1 var2) = var1mx var2mx	
		MEAN(var1 var2) = var1mn var2mn		
		STD (var1 var2) = var1sd var2sd
		N   (var1 var2) = var1n  var2n;	 * A total of 8 new variables;
		* Function(old vars) = new vars;
RUN;

* Merging summary file back into original data;
DATA work.datafilename;
	MERGE work.datafilename work.summaryfile;
	BY ID;
* Dropping unnecessary variables in summary data created by PROC MEANS;
	DROP _TYPE_ _FREQ_;
RUN;


